@@ -48,8 +48,13 @@ typedef struct _GnomeMessageBoxPrivate GnomeMessageBoxPrivate;
 typedef struct _GnomeMessageBoxClass   GnomeMessageBoxClass;
 typedef struct _GnomeMessageBoxButton  GnomeMessageBoxButton;
 
+/**
+ * GnomeMessageBox:
+ * @dialog: A #GnomeDialog widget holding the contents of the message box.
+ */
 struct _GnomeMessageBox
 {
+  /*< public >*/
   GnomeDialog dialog;
   /*< private >*/
   GnomeMessageBoxPrivate *_priv;
@@ -63,13 +68,18 @@ struct _GnomeMessageBoxClass
 
 GType      gnome_message_box_get_type   (void) G_GNUC_CONST;
 GtkWidget* gnome_message_box_new        (const gchar           *message,
-					 const gchar           *messagebox_type,
+					 const gchar          *message_box_type,
 					 ...);
 
 GtkWidget* gnome_message_box_newv       (const gchar           *message,
-					 const gchar           *messagebox_type,
+					 const gchar          *message_box_type,
 					 const gchar          **buttons);
 
+void        gnome_message_box_construct  (GnomeMessageBox      *messagebox,
+					  const gchar          *message,
+					  const gchar         *message_box_type,
+					  const gchar         **buttons);
+
 G_END_DECLS
 
 #endif /* GNOME_DISABLE_DEPRECATED */
